# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.maxLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_7.setObjectName("maxLabel_7")
        self.gridLayout_2.addWidget(self.maxLabel_7, 10, 4, 1, 1)
        self.minSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox.setObjectName("minSpinBox")
        self.gridLayout_2.addWidget(self.minSpinBox, 4, 3, 1, 1)
        self.PredictionComboBox = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox.setObjectName("PredictionComboBox")
        self.gridLayout_2.addWidget(self.PredictionComboBox, 4, 1, 1, 1)
        self.PredictionComboBox_15 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_15.setObjectName("PredictionComboBox_15")
        self.gridLayout_2.addWidget(self.PredictionComboBox_15, 18, 1, 1, 1)
        self.maxSpinBox_5 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_5.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_5.setObjectName("maxSpinBox_5")
        self.gridLayout_2.addWidget(self.maxSpinBox_5, 8, 5, 1, 1)
        self.referencePredictionComboBox = QtWidgets.QComboBox(self.groupBox)
        self.referencePredictionComboBox.setObjectName("referencePredictionComboBox")
        self.gridLayout_2.addWidget(self.referencePredictionComboBox, 1, 1, 1, 1)
        self.maxSpinBox_12 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_12.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_12.setObjectName("maxSpinBox_12")
        self.gridLayout_2.addWidget(self.maxSpinBox_12, 15, 5, 1, 1)
        self.PredictionComboBox_12 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_12.setObjectName("PredictionComboBox_12")
        self.gridLayout_2.addWidget(self.PredictionComboBox_12, 15, 1, 1, 1)
        self.PredictionComboBox_8 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_8.setObjectName("PredictionComboBox_8")
        self.gridLayout_2.addWidget(self.PredictionComboBox_8, 11, 1, 1, 1)
        self.maxSpinBox_15 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_15.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_15.setObjectName("maxSpinBox_15")
        self.gridLayout_2.addWidget(self.maxSpinBox_15, 18, 5, 1, 1)
        self.maxLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_14.setObjectName("maxLabel_14")
        self.gridLayout_2.addWidget(self.maxLabel_14, 17, 4, 1, 1)
        self.maxLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_2.setObjectName("maxLabel_2")
        self.gridLayout_2.addWidget(self.maxLabel_2, 5, 4, 1, 1)
        self.PredictionComboBox_2 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_2.setObjectName("PredictionComboBox_2")
        self.gridLayout_2.addWidget(self.PredictionComboBox_2, 5, 1, 1, 1)
        self.highPredictionComboBox = QtWidgets.QComboBox(self.groupBox)
        self.highPredictionComboBox.setObjectName("highPredictionComboBox")
        self.gridLayout_2.addWidget(self.highPredictionComboBox, 19, 1, 1, 1)
        self.minLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_6.setObjectName("minLabel_6")
        self.gridLayout_2.addWidget(self.minLabel_6, 9, 2, 1, 1)
        self.minLabel = QtWidgets.QLabel(self.groupBox)
        self.minLabel.setObjectName("minLabel")
        self.gridLayout_2.addWidget(self.minLabel, 4, 2, 1, 1)
        self.minLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_4.setObjectName("minLabel_4")
        self.gridLayout_2.addWidget(self.minLabel_4, 7, 2, 1, 1)
        self.maxSpinBox_8 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_8.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_8.setObjectName("maxSpinBox_8")
        self.gridLayout_2.addWidget(self.maxSpinBox_8, 11, 5, 1, 1)
        self.maxLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_5.setObjectName("maxLabel_5")
        self.gridLayout_2.addWidget(self.maxLabel_5, 8, 4, 1, 1)
        self.maxSpinBox_6 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_6.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_6.setObjectName("maxSpinBox_6")
        self.gridLayout_2.addWidget(self.maxSpinBox_6, 9, 5, 1, 1)
        self.maxSpinBox_7 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_7.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_7.setObjectName("maxSpinBox_7")
        self.gridLayout_2.addWidget(self.maxSpinBox_7, 10, 5, 1, 1)
        self.referencePredictionLabel = QtWidgets.QLabel(self.groupBox)
        self.referencePredictionLabel.setObjectName("referencePredictionLabel")
        self.gridLayout_2.addWidget(self.referencePredictionLabel, 1, 0, 1, 1)
        self.minLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_3.setObjectName("minLabel_3")
        self.gridLayout_2.addWidget(self.minLabel_3, 6, 2, 1, 1)
        self.maxLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_6.setObjectName("maxLabel_6")
        self.gridLayout_2.addWidget(self.maxLabel_6, 9, 4, 1, 1)
        self.lowPredictionMaxLabel = QtWidgets.QLabel(self.groupBox)
        self.lowPredictionMaxLabel.setMaximumSize(QtCore.QSize(30, 16777215))
        self.lowPredictionMaxLabel.setObjectName("lowPredictionMaxLabel")
        self.gridLayout_2.addWidget(self.lowPredictionMaxLabel, 3, 2, 1, 1)
        self.minLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_9.setObjectName("minLabel_9")
        self.gridLayout_2.addWidget(self.minLabel_9, 12, 2, 1, 1)
        self.maxSpinBox_10 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_10.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_10.setObjectName("maxSpinBox_10")
        self.gridLayout_2.addWidget(self.maxSpinBox_10, 13, 5, 1, 1)
        self.minSpinBox_12 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_12.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_12.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_12.setObjectName("minSpinBox_12")
        self.gridLayout_2.addWidget(self.minSpinBox_12, 15, 3, 1, 1)
        self.PredictionComboBox_9 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_9.setObjectName("PredictionComboBox_9")
        self.gridLayout_2.addWidget(self.PredictionComboBox_9, 12, 1, 1, 1)
        self.highPredictionMinSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.highPredictionMinSpinBox.setMinimumSize(QtCore.QSize(130, 0))
        self.highPredictionMinSpinBox.setMaximumSize(QtCore.QSize(70, 16777215))
        self.highPredictionMinSpinBox.setObjectName("highPredictionMinSpinBox")
        self.gridLayout_2.addWidget(self.highPredictionMinSpinBox, 19, 3, 1, 1)
        self.PredictionComboBox_11 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_11.setObjectName("PredictionComboBox_11")
        self.gridLayout_2.addWidget(self.PredictionComboBox_11, 14, 1, 1, 1)
        self.PredictionComboBox_4 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_4.setObjectName("PredictionComboBox_4")
        self.gridLayout_2.addWidget(self.PredictionComboBox_4, 7, 1, 1, 1)
        self.minSpinBox_7 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_7.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_7.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_7.setObjectName("minSpinBox_7")
        self.gridLayout_2.addWidget(self.minSpinBox_7, 10, 3, 1, 1)
        self.PredictionComboBox_5 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_5.setObjectName("PredictionComboBox_5")
        self.gridLayout_2.addWidget(self.PredictionComboBox_5, 8, 1, 1, 1)
        self.maxSpinBox_3 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_3.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_3.setObjectName("maxSpinBox_3")
        self.gridLayout_2.addWidget(self.maxSpinBox_3, 6, 5, 1, 1)
        self.minSpinBox_6 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_6.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_6.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_6.setObjectName("minSpinBox_6")
        self.gridLayout_2.addWidget(self.minSpinBox_6, 9, 3, 1, 1)
        self.minSpinBox_8 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_8.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_8.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_8.setObjectName("minSpinBox_8")
        self.gridLayout_2.addWidget(self.minSpinBox_8, 11, 3, 1, 1)
        self.maxLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_11.setObjectName("maxLabel_11")
        self.gridLayout_2.addWidget(self.maxLabel_11, 14, 4, 1, 1)
        self.maxLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_3.setObjectName("maxLabel_3")
        self.gridLayout_2.addWidget(self.maxLabel_3, 6, 4, 1, 1)
        self.highPredictionLabel = QtWidgets.QLabel(self.groupBox)
        self.highPredictionLabel.setObjectName("highPredictionLabel")
        self.gridLayout_2.addWidget(self.highPredictionLabel, 19, 0, 1, 1)
        self.PredictionComboBox_13 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_13.setObjectName("PredictionComboBox_13")
        self.gridLayout_2.addWidget(self.PredictionComboBox_13, 16, 1, 1, 1)
        self.minSpinBox_11 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_11.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_11.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_11.setObjectName("minSpinBox_11")
        self.gridLayout_2.addWidget(self.minSpinBox_11, 14, 3, 1, 1)
        self.minLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_2.setObjectName("minLabel_2")
        self.gridLayout_2.addWidget(self.minLabel_2, 5, 2, 1, 1)
        self.minSpinBox_3 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_3.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_3.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_3.setObjectName("minSpinBox_3")
        self.gridLayout_2.addWidget(self.minSpinBox_3, 6, 3, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.addSubPushButton = QtWidgets.QPushButton(self.groupBox)
        self.addSubPushButton.setObjectName("addSubPushButton")
        self.horizontalLayout.addWidget(self.addSubPushButton)
        self.deleteSubPushButton = QtWidgets.QPushButton(self.groupBox)
        self.deleteSubPushButton.setObjectName("deleteSubPushButton")
        self.horizontalLayout.addWidget(self.deleteSubPushButton)
        self.optimizeSubRangesCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.optimizeSubRangesCheckBox.setObjectName("optimizeSubRangesCheckBox")
        self.horizontalLayout.addWidget(self.optimizeSubRangesCheckBox)
        self.gridLayout_2.addLayout(self.horizontalLayout, 20, 0, 1, 6)
        self.PredictionComboBox_14 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_14.setObjectName("PredictionComboBox_14")
        self.gridLayout_2.addWidget(self.PredictionComboBox_14, 17, 1, 1, 1)
        self.minLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_14.setObjectName("minLabel_14")
        self.gridLayout_2.addWidget(self.minLabel_14, 17, 2, 1, 1)
        self.minLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_11.setObjectName("minLabel_11")
        self.gridLayout_2.addWidget(self.minLabel_11, 14, 2, 1, 1)
        self.maxSpinBox_4 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_4.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_4.setObjectName("maxSpinBox_4")
        self.gridLayout_2.addWidget(self.maxSpinBox_4, 7, 5, 1, 1)
        self.lowPredictionComboBox = QtWidgets.QComboBox(self.groupBox)
        self.lowPredictionComboBox.setObjectName("lowPredictionComboBox")
        self.gridLayout_2.addWidget(self.lowPredictionComboBox, 3, 1, 1, 1)
        self.maxLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_9.setObjectName("maxLabel_9")
        self.gridLayout_2.addWidget(self.maxLabel_9, 12, 4, 1, 1)
        self.highPredictionMinLabel = QtWidgets.QLabel(self.groupBox)
        self.highPredictionMinLabel.setObjectName("highPredictionMinLabel")
        self.gridLayout_2.addWidget(self.highPredictionMinLabel, 19, 2, 1, 1)
        self.minLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_13.setObjectName("minLabel_13")
        self.gridLayout_2.addWidget(self.minLabel_13, 16, 2, 1, 1)
        self.lowPredictionMaxSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.lowPredictionMaxSpinBox.setMinimumSize(QtCore.QSize(130, 0))
        self.lowPredictionMaxSpinBox.setMaximumSize(QtCore.QSize(910, 16777215))
        self.lowPredictionMaxSpinBox.setObjectName("lowPredictionMaxSpinBox")
        self.gridLayout_2.addWidget(self.lowPredictionMaxSpinBox, 3, 3, 1, 1)
        self.minLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_15.setObjectName("minLabel_15")
        self.gridLayout_2.addWidget(self.minLabel_15, 18, 2, 1, 1)
        self.minLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_5.setObjectName("minLabel_5")
        self.gridLayout_2.addWidget(self.minLabel_5, 8, 2, 1, 1)
        self.PredictionComboBox_10 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_10.setObjectName("PredictionComboBox_10")
        self.gridLayout_2.addWidget(self.PredictionComboBox_10, 13, 1, 1, 1)
        self.minSpinBox_4 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_4.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_4.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_4.setObjectName("minSpinBox_4")
        self.gridLayout_2.addWidget(self.minSpinBox_4, 7, 3, 1, 1)
        self.PredictionComboBox_3 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_3.setObjectName("PredictionComboBox_3")
        self.gridLayout_2.addWidget(self.PredictionComboBox_3, 6, 1, 1, 1)
        self.maxLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_4.setObjectName("maxLabel_4")
        self.gridLayout_2.addWidget(self.maxLabel_4, 7, 4, 1, 1)
        self.minSpinBox_5 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_5.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_5.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_5.setObjectName("minSpinBox_5")
        self.gridLayout_2.addWidget(self.minSpinBox_5, 8, 3, 1, 1)
        self.PredictionComboBox_6 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_6.setObjectName("PredictionComboBox_6")
        self.gridLayout_2.addWidget(self.PredictionComboBox_6, 9, 1, 1, 1)
        self.lowPredictionLabel = QtWidgets.QLabel(self.groupBox)
        self.lowPredictionLabel.setObjectName("lowPredictionLabel")
        self.gridLayout_2.addWidget(self.lowPredictionLabel, 3, 0, 1, 1)
        self.chooseDatalabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDatalabel.setObjectName("chooseDatalabel")
        self.gridLayout_2.addWidget(self.chooseDatalabel, 0, 0, 1, 1)
        self.maxLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_13.setObjectName("maxLabel_13")
        self.gridLayout_2.addWidget(self.maxLabel_13, 16, 4, 1, 1)
        self.minSpinBox_13 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_13.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_13.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_13.setObjectName("minSpinBox_13")
        self.gridLayout_2.addWidget(self.minSpinBox_13, 16, 3, 1, 1)
        self.maxLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_12.setObjectName("maxLabel_12")
        self.gridLayout_2.addWidget(self.maxLabel_12, 15, 4, 1, 1)
        self.minSpinBox_10 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_10.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_10.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_10.setObjectName("minSpinBox_10")
        self.gridLayout_2.addWidget(self.minSpinBox_10, 13, 3, 1, 1)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.gridLayout_2.addWidget(self.chooseDataComboBox, 0, 1, 1, 1)
        self.maxSpinBox_14 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_14.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_14.setObjectName("maxSpinBox_14")
        self.gridLayout_2.addWidget(self.maxSpinBox_14, 17, 5, 1, 1)
        self.minSpinBox_14 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_14.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_14.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_14.setObjectName("minSpinBox_14")
        self.gridLayout_2.addWidget(self.minSpinBox_14, 17, 3, 1, 1)
        self.minLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_12.setObjectName("minLabel_12")
        self.gridLayout_2.addWidget(self.minLabel_12, 15, 2, 1, 1)
        self.minSpinBox_15 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_15.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_15.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_15.setObjectName("minSpinBox_15")
        self.gridLayout_2.addWidget(self.minSpinBox_15, 18, 3, 1, 1)
        self.maxSpinBox_13 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_13.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_13.setObjectName("maxSpinBox_13")
        self.gridLayout_2.addWidget(self.maxSpinBox_13, 16, 5, 1, 1)
        self.maxLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_10.setObjectName("maxLabel_10")
        self.gridLayout_2.addWidget(self.maxLabel_10, 13, 4, 1, 1)
        self.maxSpinBox_11 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_11.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_11.setObjectName("maxSpinBox_11")
        self.gridLayout_2.addWidget(self.maxSpinBox_11, 14, 5, 1, 1)
        self.maxLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_15.setObjectName("maxLabel_15")
        self.gridLayout_2.addWidget(self.maxLabel_15, 18, 4, 1, 1)
        self.minSpinBox_9 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_9.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_9.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_9.setObjectName("minSpinBox_9")
        self.gridLayout_2.addWidget(self.minSpinBox_9, 12, 3, 1, 1)
        self.maxLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_8.setObjectName("maxLabel_8")
        self.gridLayout_2.addWidget(self.maxLabel_8, 11, 4, 1, 1)
        self.minLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_10.setObjectName("minLabel_10")
        self.gridLayout_2.addWidget(self.minLabel_10, 13, 2, 1, 1)
        self.minSpinBox_2 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minSpinBox_2.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_2.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_2.setObjectName("minSpinBox_2")
        self.gridLayout_2.addWidget(self.minSpinBox_2, 5, 3, 1, 1)
        self.maxSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox.setObjectName("maxSpinBox")
        self.gridLayout_2.addWidget(self.maxSpinBox, 4, 5, 1, 1)
        self.minLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_7.setObjectName("minLabel_7")
        self.gridLayout_2.addWidget(self.minLabel_7, 10, 2, 1, 1)
        self.PredictionComboBox_7 = QtWidgets.QComboBox(self.groupBox)
        self.PredictionComboBox_7.setObjectName("PredictionComboBox_7")
        self.gridLayout_2.addWidget(self.PredictionComboBox_7, 10, 1, 1, 1)
        self.maxLabel = QtWidgets.QLabel(self.groupBox)
        self.maxLabel.setMaximumSize(QtCore.QSize(30, 16777215))
        self.maxLabel.setObjectName("maxLabel")
        self.gridLayout_2.addWidget(self.maxLabel, 4, 4, 1, 1)
        self.minLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_8.setObjectName("minLabel_8")
        self.gridLayout_2.addWidget(self.minLabel_8, 11, 2, 1, 1)
        self.maxSpinBox_2 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_2.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_2.setObjectName("maxSpinBox_2")
        self.gridLayout_2.addWidget(self.maxSpinBox_2, 5, 5, 1, 1)
        self.formLayout_3 = QtWidgets.QFormLayout()
        self.formLayout_3.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_3.setFormAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.formLayout_3.setObjectName("formLayout_3")
        self.optimizeSubRangesLabel = QtWidgets.QLabel(self.groupBox)
        self.optimizeSubRangesLabel.setObjectName("optimizeSubRangesLabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.optimizeSubRangesLabel)
        self.optimizeSubRangesComboBox = QtWidgets.QComboBox(self.groupBox)
        self.optimizeSubRangesComboBox.setObjectName("optimizeSubRangesComboBox")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.optimizeSubRangesComboBox)
        self.gridLayout_2.addLayout(self.formLayout_3, 21, 0, 1, 6)
        self.maxSpinBox_9 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxSpinBox_9.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_9.setObjectName("maxSpinBox_9")
        self.gridLayout_2.addWidget(self.maxSpinBox_9, 12, 5, 1, 1)
        self.index_spin = QtWidgets.QSpinBox(self.groupBox)
        self.index_spin.setObjectName("index_spin")
        self.gridLayout_2.addWidget(self.index_spin, 2, 1, 1, 1)
        self.gridLayout.addWidget(self.groupBox, 0, 0, 1, 1)

        self.retranslateUi(Form)
        self.optimizeSubRangesCheckBox.toggled['bool'].connect(self.optimizeSubRangesComboBox.setVisible)
        self.optimizeSubRangesCheckBox.toggled['bool'].connect(self.optimizeSubRangesLabel.setVisible)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.referencePredictionComboBox, self.lowPredictionComboBox)
        Form.setTabOrder(self.lowPredictionComboBox, self.lowPredictionMaxSpinBox)
        Form.setTabOrder(self.lowPredictionMaxSpinBox, self.PredictionComboBox)
        Form.setTabOrder(self.PredictionComboBox, self.minSpinBox)
        Form.setTabOrder(self.minSpinBox, self.maxSpinBox)
        Form.setTabOrder(self.maxSpinBox, self.PredictionComboBox_2)
        Form.setTabOrder(self.PredictionComboBox_2, self.minSpinBox_2)
        Form.setTabOrder(self.minSpinBox_2, self.maxSpinBox_2)
        Form.setTabOrder(self.maxSpinBox_2, self.PredictionComboBox_3)
        Form.setTabOrder(self.PredictionComboBox_3, self.minSpinBox_3)
        Form.setTabOrder(self.minSpinBox_3, self.maxSpinBox_3)
        Form.setTabOrder(self.maxSpinBox_3, self.PredictionComboBox_4)
        Form.setTabOrder(self.PredictionComboBox_4, self.minSpinBox_4)
        Form.setTabOrder(self.minSpinBox_4, self.maxSpinBox_4)
        Form.setTabOrder(self.maxSpinBox_4, self.PredictionComboBox_5)
        Form.setTabOrder(self.PredictionComboBox_5, self.minSpinBox_5)
        Form.setTabOrder(self.minSpinBox_5, self.maxSpinBox_5)
        Form.setTabOrder(self.maxSpinBox_5, self.PredictionComboBox_6)
        Form.setTabOrder(self.PredictionComboBox_6, self.minSpinBox_6)
        Form.setTabOrder(self.minSpinBox_6, self.maxSpinBox_6)
        Form.setTabOrder(self.maxSpinBox_6, self.PredictionComboBox_7)
        Form.setTabOrder(self.PredictionComboBox_7, self.minSpinBox_7)
        Form.setTabOrder(self.minSpinBox_7, self.maxSpinBox_7)
        Form.setTabOrder(self.maxSpinBox_7, self.PredictionComboBox_8)
        Form.setTabOrder(self.PredictionComboBox_8, self.minSpinBox_8)
        Form.setTabOrder(self.minSpinBox_8, self.maxSpinBox_8)
        Form.setTabOrder(self.maxSpinBox_8, self.PredictionComboBox_9)
        Form.setTabOrder(self.PredictionComboBox_9, self.minSpinBox_9)
        Form.setTabOrder(self.minSpinBox_9, self.maxSpinBox_9)
        Form.setTabOrder(self.maxSpinBox_9, self.PredictionComboBox_10)
        Form.setTabOrder(self.PredictionComboBox_10, self.minSpinBox_10)
        Form.setTabOrder(self.minSpinBox_10, self.maxSpinBox_10)
        Form.setTabOrder(self.maxSpinBox_10, self.PredictionComboBox_11)
        Form.setTabOrder(self.PredictionComboBox_11, self.minSpinBox_11)
        Form.setTabOrder(self.minSpinBox_11, self.maxSpinBox_11)
        Form.setTabOrder(self.maxSpinBox_11, self.PredictionComboBox_12)
        Form.setTabOrder(self.PredictionComboBox_12, self.minSpinBox_12)
        Form.setTabOrder(self.minSpinBox_12, self.maxSpinBox_12)
        Form.setTabOrder(self.maxSpinBox_12, self.PredictionComboBox_13)
        Form.setTabOrder(self.PredictionComboBox_13, self.minSpinBox_13)
        Form.setTabOrder(self.minSpinBox_13, self.maxSpinBox_13)
        Form.setTabOrder(self.maxSpinBox_13, self.PredictionComboBox_14)
        Form.setTabOrder(self.PredictionComboBox_14, self.minSpinBox_14)
        Form.setTabOrder(self.minSpinBox_14, self.maxSpinBox_14)
        Form.setTabOrder(self.maxSpinBox_14, self.PredictionComboBox_15)
        Form.setTabOrder(self.PredictionComboBox_15, self.minSpinBox_15)
        Form.setTabOrder(self.minSpinBox_15, self.maxSpinBox_15)
        Form.setTabOrder(self.maxSpinBox_15, self.highPredictionComboBox)
        Form.setTabOrder(self.highPredictionComboBox, self.highPredictionMinSpinBox)
        Form.setTabOrder(self.highPredictionMinSpinBox, self.addSubPushButton)
        Form.setTabOrder(self.addSubPushButton, self.deleteSubPushButton)
        Form.setTabOrder(self.deleteSubPushButton, self.optimizeSubRangesCheckBox)
        Form.setTabOrder(self.optimizeSubRangesCheckBox, self.optimizeSubRangesComboBox)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Blend Submodel Predictions"))
        self.maxLabel_7.setText(("Max"))
        self.maxLabel_14.setText(("Max"))
        self.maxLabel_2.setText(("Max"))
        self.minLabel_6.setText(("Min"))
        self.minLabel.setText(("Min"))
        self.minLabel_4.setText(("Min"))
        self.maxLabel_5.setText(("Max"))
        self.referencePredictionLabel.setText(("Choose reference model prediction: "))
        self.minLabel_3.setText(("Min"))
        self.maxLabel_6.setText(("Max"))
        self.lowPredictionMaxLabel.setText(("Max"))
        self.minLabel_9.setText(("Min"))
        self.maxLabel_11.setText(("Max"))
        self.maxLabel_3.setText(("Max"))
        self.highPredictionLabel.setText(("High Model Prediction"))
        self.minLabel_2.setText(("Min"))
        self.addSubPushButton.setText(("Add submodel prediction"))
        self.deleteSubPushButton.setText(("Delete submodel prediction"))
        self.optimizeSubRangesCheckBox.setText(("Optimize "))
        self.minLabel_14.setText(("Min"))
        self.minLabel_11.setText(("Min"))
        self.maxLabel_9.setText(("Max"))
        self.highPredictionMinLabel.setText(("Min"))
        self.minLabel_13.setText(("Min"))
        self.minLabel_15.setText(("Min"))
        self.minLabel_5.setText(("Min"))
        self.maxLabel_4.setText(("Max"))
        self.lowPredictionLabel.setText(("Low Model Prediction"))
        self.chooseDatalabel.setText(("Choose data"))
        self.maxLabel_13.setText(("Max"))
        self.maxLabel_12.setText(("Max"))
        self.minLabel_12.setText(("Min"))
        self.maxLabel_10.setText(("Max"))
        self.maxLabel_15.setText(("Max"))
        self.maxLabel_8.setText(("Max"))
        self.minLabel_10.setText(("Min"))
        self.minLabel_7.setText(("Min"))
        self.maxLabel.setText(("Max"))
        self.minLabel_8.setText(("Min"))
        self.optimizeSubRangesLabel.setText(("Choose reference to optimize blending ranges:"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

