# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.elasticNetGroupBox = QtWidgets.QGroupBox(Form)
        self.elasticNetGroupBox.setTitle("")
        self.elasticNetGroupBox.setObjectName("elasticNetGroupBox")
        self.ElasticNet = QtWidgets.QFormLayout(self.elasticNetGroupBox)
        self.ElasticNet.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.ElasticNet.setObjectName("ElasticNet")
        self.minalpha_label = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.minalpha_label.setObjectName("minalpha_label")
        self.ElasticNet.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.minalpha_label)
        self.minalpha_spin = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.minalpha_spin.setDecimals(20)
        self.minalpha_spin.setMaximum(999999999.0)
        self.minalpha_spin.setObjectName("minalpha_spin")
        self.ElasticNet.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.minalpha_spin)
        self.maxalpha_label = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.maxalpha_label.setObjectName("maxalpha_label")
        self.ElasticNet.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.maxalpha_label)
        self.maxalpha_spin = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.maxalpha_spin.setDecimals(20)
        self.maxalpha_spin.setMaximum(999999999.0)
        self.maxalpha_spin.setObjectName("maxalpha_spin")
        self.ElasticNet.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.maxalpha_spin)
        self.nalpha_label = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.nalpha_label.setToolTip("")
        self.nalpha_label.setObjectName("nalpha_label")
        self.ElasticNet.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.nalpha_label)
        self.nalpha_spin = QtWidgets.QSpinBox(self.elasticNetGroupBox)
        self.nalpha_spin.setToolTip("")
        self.nalpha_spin.setMaximum(999999999)
        self.nalpha_spin.setObjectName("nalpha_spin")
        self.ElasticNet.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.nalpha_spin)
        self.enl1_ratioLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enl1_ratioLabel.setObjectName("enl1_ratioLabel")
        self.ElasticNet.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.enl1_ratioLabel)
        self.enl1_ratioLineEdit = QtWidgets.QLineEdit(self.elasticNetGroupBox)
        self.enl1_ratioLineEdit.setObjectName("enl1_ratioLineEdit")
        self.ElasticNet.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.enl1_ratioLineEdit)
        self.enmax_iterLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enmax_iterLabel.setObjectName("enmax_iterLabel")
        self.ElasticNet.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.enmax_iterLabel)
        self.enmax_iterLineEdit = QtWidgets.QLineEdit(self.elasticNetGroupBox)
        self.enmax_iterLineEdit.setObjectName("enmax_iterLineEdit")
        self.ElasticNet.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.enmax_iterLineEdit)
        self.entolLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.entolLabel.setObjectName("entolLabel")
        self.ElasticNet.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.entolLabel)
        self.entolLineEdit = QtWidgets.QLineEdit(self.elasticNetGroupBox)
        self.entolLineEdit.setObjectName("entolLineEdit")
        self.ElasticNet.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.entolLineEdit)
        self.enpositiveLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enpositiveLabel.setObjectName("enpositiveLabel")
        self.ElasticNet.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.enpositiveLabel)
        self.enpositive_list = QtWidgets.QListWidget(self.elasticNetGroupBox)
        self.enpositive_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.enpositive_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.enpositive_list.setObjectName("enpositive_list")
        item = QtWidgets.QListWidgetItem()
        self.enpositive_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.enpositive_list.addItem(item)
        self.ElasticNet.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.enpositive_list)
        self.enfit_interceptLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enfit_interceptLabel.setObjectName("enfit_interceptLabel")
        self.ElasticNet.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.enfit_interceptLabel)
        self.enfit_intercept_list = QtWidgets.QListWidget(self.elasticNetGroupBox)
        self.enfit_intercept_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.enfit_intercept_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.enfit_intercept_list.setObjectName("enfit_intercept_list")
        item = QtWidgets.QListWidgetItem()
        self.enfit_intercept_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.enfit_intercept_list.addItem(item)
        self.ElasticNet.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.enfit_intercept_list)
        self.verticalLayout.addWidget(self.elasticNetGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.minalpha_label.setText(("Min Alpha"))
        self.maxalpha_label.setText(("Max Alpha"))
        self.nalpha_label.setText(("# of Alphas"))
        self.enl1_ratioLabel.setText(("L1 ratio"))
        self.enl1_ratioLineEdit.setText((".1, .5, .7, .9, .95, .99, 1"))
        self.enmax_iterLabel.setText(("Max. # of iterations"))
        self.enmax_iterLineEdit.setText(("1000"))
        self.entolLabel.setText(("Tolerance"))
        self.entolLineEdit.setText(("0.0001"))
        self.enpositiveLabel.setText(("Force Positive Coefficients"))
        __sortingEnabled = self.enpositive_list.isSortingEnabled()
        self.enpositive_list.setSortingEnabled(False)
        item = self.enpositive_list.item(0)
        item.setText(("True"))
        item = self.enpositive_list.item(1)
        item.setText(("False"))
        self.enpositive_list.setSortingEnabled(__sortingEnabled)
        self.enfit_interceptLabel.setText(("Fit Intercept"))
        __sortingEnabled = self.enfit_intercept_list.isSortingEnabled()
        self.enfit_intercept_list.setSortingEnabled(False)
        item = self.enfit_intercept_list.item(0)
        item.setText(("True"))
        item = self.enfit_intercept_list.item(1)
        item.setText(("False"))
        self.enfit_intercept_list.setSortingEnabled(__sortingEnabled)


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

