# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.Normalization = QtWidgets.QVBoxLayout(self.groupBox)
        self.Normalization.setObjectName("Normalization")
        self.chooseDataFormLayout = QtWidgets.QFormLayout()
        self.chooseDataFormLayout.setObjectName("chooseDataFormLayout")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.chooseDataFormLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chooseDataLabel)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.chooseDataFormLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.chooseDataComboBox)
        self.Normalization.addLayout(self.chooseDataFormLayout)
        self.varToNormalizeVerticalLayout = QtWidgets.QVBoxLayout()
        self.varToNormalizeVerticalLayout.setObjectName("varToNormalizeVerticalLayout")
        self.varToNormalizeLabel = QtWidgets.QLabel(self.groupBox)
        self.varToNormalizeLabel.setObjectName("varToNormalizeLabel")
        self.varToNormalizeVerticalLayout.addWidget(self.varToNormalizeLabel)
        self.varToNormalizeListWidget = QtWidgets.QListWidget(self.groupBox)
        self.varToNormalizeListWidget.setObjectName("varToNormalizeListWidget")
        self.varToNormalizeVerticalLayout.addWidget(self.varToNormalizeListWidget)
        self.Normalization.addLayout(self.varToNormalizeVerticalLayout)
        self.waveLengthLayout = QtWidgets.QGridLayout()
        self.waveLengthLayout.setObjectName("waveLengthLayout")
        self.hidden_6 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_6.setObjectName("hidden_6")
        self.waveLengthLayout.addWidget(self.hidden_6, 5, 4, 1, 1)
        self.hidden_4 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_4.setObjectName("hidden_4")
        self.waveLengthLayout.addWidget(self.hidden_4, 3, 4, 1, 1)
        self.hidden_1 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_1.setChecked(False)
        self.hidden_1.setObjectName("hidden_1")
        self.waveLengthLayout.addWidget(self.hidden_1, 0, 4, 1, 1)
        self.minWvlLabel = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel.setObjectName("minWvlLabel")
        self.waveLengthLayout.addWidget(self.minWvlLabel, 0, 0, 1, 1)
        self.maxWvlLabel = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel.setObjectName("maxWvlLabel")
        self.waveLengthLayout.addWidget(self.maxWvlLabel, 0, 2, 1, 1)
        self.minWvlLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_2.setObjectName("minWvlLabel_2")
        self.waveLengthLayout.addWidget(self.minWvlLabel_2, 1, 0, 1, 1)
        self.maxWvlLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_2.setObjectName("maxWvlLabel_2")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_2, 1, 2, 1, 1)
        self.minWvlLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_3.setObjectName("minWvlLabel_3")
        self.waveLengthLayout.addWidget(self.minWvlLabel_3, 2, 0, 1, 1)
        self.maxWvlLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_3.setObjectName("maxWvlLabel_3")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_3, 2, 2, 1, 1)
        self.minWvlLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_4.setObjectName("minWvlLabel_4")
        self.waveLengthLayout.addWidget(self.minWvlLabel_4, 3, 0, 1, 1)
        self.maxWvlLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_4.setObjectName("maxWvlLabel_4")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_4, 3, 2, 1, 1)
        self.minWvlLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_5.setObjectName("minWvlLabel_5")
        self.waveLengthLayout.addWidget(self.minWvlLabel_5, 4, 0, 1, 1)
        self.maxWvlLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_5.setObjectName("maxWvlLabel_5")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_5, 4, 2, 1, 1)
        self.minWvlLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_6.setObjectName("minWvlLabel_6")
        self.waveLengthLayout.addWidget(self.minWvlLabel_6, 5, 0, 1, 1)
        self.maxWvlLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_6.setObjectName("maxWvlLabel_6")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_6, 5, 2, 1, 1)
        self.minWvlLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_7.setObjectName("minWvlLabel_7")
        self.waveLengthLayout.addWidget(self.minWvlLabel_7, 6, 0, 1, 1)
        self.maxWvlLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_7.setObjectName("maxWvlLabel_7")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_7, 6, 2, 1, 1)
        self.minWvlLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_8.setObjectName("minWvlLabel_8")
        self.waveLengthLayout.addWidget(self.minWvlLabel_8, 7, 0, 1, 1)
        self.maxWvlLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_8.setObjectName("maxWvlLabel_8")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_8, 7, 2, 1, 1)
        self.minWvlLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_9.setObjectName("minWvlLabel_9")
        self.waveLengthLayout.addWidget(self.minWvlLabel_9, 8, 0, 1, 1)
        self.maxWvlLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_9.setObjectName("maxWvlLabel_9")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_9, 8, 2, 1, 1)
        self.minWvlLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_10.setObjectName("minWvlLabel_10")
        self.waveLengthLayout.addWidget(self.minWvlLabel_10, 9, 0, 1, 1)
        self.maxWvlLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_10.setObjectName("maxWvlLabel_10")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_10, 9, 2, 1, 1)
        self.minWvlLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_11.setObjectName("minWvlLabel_11")
        self.waveLengthLayout.addWidget(self.minWvlLabel_11, 10, 0, 1, 1)
        self.maxWvlLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_11.setObjectName("maxWvlLabel_11")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_11, 10, 2, 1, 1)
        self.minWvlLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_12.setObjectName("minWvlLabel_12")
        self.waveLengthLayout.addWidget(self.minWvlLabel_12, 11, 0, 1, 1)
        self.maxWvlLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_12.setObjectName("maxWvlLabel_12")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_12, 11, 2, 1, 1)
        self.minWvlLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_13.setObjectName("minWvlLabel_13")
        self.waveLengthLayout.addWidget(self.minWvlLabel_13, 12, 0, 1, 1)
        self.maxWvlLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_13.setObjectName("maxWvlLabel_13")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_13, 12, 2, 1, 1)
        self.minWvlLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_14.setObjectName("minWvlLabel_14")
        self.waveLengthLayout.addWidget(self.minWvlLabel_14, 13, 0, 1, 1)
        self.maxWvlLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_14.setObjectName("maxWvlLabel_14")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_14, 13, 2, 1, 1)
        self.minWvlLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_15.setObjectName("minWvlLabel_15")
        self.waveLengthLayout.addWidget(self.minWvlLabel_15, 14, 0, 1, 1)
        self.maxWvlLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_15.setObjectName("maxWvlLabel_15")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_15, 14, 2, 1, 1)
        self.minWvlSpin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin.setObjectName("minWvlSpin")
        self.waveLengthLayout.addWidget(self.minWvlSpin, 0, 1, 1, 1)
        self.minWvlSpin_10 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_10.setObjectName("minWvlSpin_10")
        self.waveLengthLayout.addWidget(self.minWvlSpin_10, 9, 1, 1, 1)
        self.minWvlSpin_11 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_11.setObjectName("minWvlSpin_11")
        self.waveLengthLayout.addWidget(self.minWvlSpin_11, 10, 1, 1, 1)
        self.minWvlSpin_12 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_12.setObjectName("minWvlSpin_12")
        self.waveLengthLayout.addWidget(self.minWvlSpin_12, 11, 1, 1, 1)
        self.minWvlSpin_13 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_13.setObjectName("minWvlSpin_13")
        self.waveLengthLayout.addWidget(self.minWvlSpin_13, 12, 1, 1, 1)
        self.minWvlSpin_14 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_14.setObjectName("minWvlSpin_14")
        self.waveLengthLayout.addWidget(self.minWvlSpin_14, 13, 1, 1, 1)
        self.minWvlSpin_15 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_15.setObjectName("minWvlSpin_15")
        self.waveLengthLayout.addWidget(self.minWvlSpin_15, 14, 1, 1, 1)
        self.minWvlSpin_2 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_2.setObjectName("minWvlSpin_2")
        self.waveLengthLayout.addWidget(self.minWvlSpin_2, 1, 1, 1, 1)
        self.minWvlSpin_3 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_3.setObjectName("minWvlSpin_3")
        self.waveLengthLayout.addWidget(self.minWvlSpin_3, 2, 1, 1, 1)
        self.minWvlSpin_4 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_4.setObjectName("minWvlSpin_4")
        self.waveLengthLayout.addWidget(self.minWvlSpin_4, 3, 1, 1, 1)
        self.minWvlSpin_5 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_5.setObjectName("minWvlSpin_5")
        self.waveLengthLayout.addWidget(self.minWvlSpin_5, 4, 1, 1, 1)
        self.minWvlSpin_6 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_6.setObjectName("minWvlSpin_6")
        self.waveLengthLayout.addWidget(self.minWvlSpin_6, 5, 1, 1, 1)
        self.minWvlSpin_7 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_7.setObjectName("minWvlSpin_7")
        self.waveLengthLayout.addWidget(self.minWvlSpin_7, 6, 1, 1, 1)
        self.minWvlSpin_8 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_8.setObjectName("minWvlSpin_8")
        self.waveLengthLayout.addWidget(self.minWvlSpin_8, 7, 1, 1, 1)
        self.minWvlSpin_9 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_9.setObjectName("minWvlSpin_9")
        self.waveLengthLayout.addWidget(self.minWvlSpin_9, 8, 1, 1, 1)
        self.maxWvlSpin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin.setObjectName("maxWvlSpin")
        self.waveLengthLayout.addWidget(self.maxWvlSpin, 0, 3, 1, 1)
        self.maxWvlSpin_10 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_10.setObjectName("maxWvlSpin_10")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_10, 9, 3, 1, 1)
        self.maxWvlSpin_11 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_11.setObjectName("maxWvlSpin_11")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_11, 10, 3, 1, 1)
        self.maxWvlSpin_12 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_12.setObjectName("maxWvlSpin_12")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_12, 11, 3, 1, 1)
        self.maxWvlSpin_13 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_13.setObjectName("maxWvlSpin_13")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_13, 12, 3, 1, 1)
        self.maxWvlSpin_14 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_14.setObjectName("maxWvlSpin_14")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_14, 13, 3, 1, 1)
        self.maxWvlSpin_15 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_15.setObjectName("maxWvlSpin_15")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_15, 14, 3, 1, 1)
        self.maxWvlSpin_2 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_2.setObjectName("maxWvlSpin_2")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_2, 1, 3, 1, 1)
        self.maxWvlSpin_3 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_3.setObjectName("maxWvlSpin_3")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_3, 2, 3, 1, 1)
        self.maxWvlSpin_4 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_4.setObjectName("maxWvlSpin_4")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_4, 3, 3, 1, 1)
        self.maxWvlSpin_5 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_5.setObjectName("maxWvlSpin_5")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_5, 4, 3, 1, 1)
        self.maxWvlSpin_6 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_6.setObjectName("maxWvlSpin_6")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_6, 5, 3, 1, 1)
        self.maxWvlSpin_7 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_7.setObjectName("maxWvlSpin_7")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_7, 6, 3, 1, 1)
        self.maxWvlSpin_8 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_8.setObjectName("maxWvlSpin_8")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_8, 7, 3, 1, 1)
        self.maxWvlSpin_9 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_9.setObjectName("maxWvlSpin_9")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_9, 8, 3, 1, 1)
        self.hidden_5 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_5.setObjectName("hidden_5")
        self.waveLengthLayout.addWidget(self.hidden_5, 4, 4, 1, 1)
        self.hidden_7 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_7.setObjectName("hidden_7")
        self.waveLengthLayout.addWidget(self.hidden_7, 6, 4, 1, 1)
        self.hidden_3 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_3.setObjectName("hidden_3")
        self.waveLengthLayout.addWidget(self.hidden_3, 2, 4, 1, 1)
        self.hidden_9 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_9.setObjectName("hidden_9")
        self.waveLengthLayout.addWidget(self.hidden_9, 8, 4, 1, 1)
        self.hidden_2 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_2.setObjectName("hidden_2")
        self.waveLengthLayout.addWidget(self.hidden_2, 1, 4, 1, 1)
        self.hidden_10 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_10.setObjectName("hidden_10")
        self.waveLengthLayout.addWidget(self.hidden_10, 9, 4, 1, 1)
        self.hidden_13 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_13.setObjectName("hidden_13")
        self.waveLengthLayout.addWidget(self.hidden_13, 12, 4, 1, 1)
        self.hidden_11 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_11.setObjectName("hidden_11")
        self.waveLengthLayout.addWidget(self.hidden_11, 10, 4, 1, 1)
        self.hidden_12 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_12.setObjectName("hidden_12")
        self.waveLengthLayout.addWidget(self.hidden_12, 11, 4, 1, 1)
        self.hidden_14 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_14.setObjectName("hidden_14")
        self.waveLengthLayout.addWidget(self.hidden_14, 13, 4, 1, 1)
        self.hidden_15 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_15.setObjectName("hidden_15")
        self.waveLengthLayout.addWidget(self.hidden_15, 14, 4, 1, 1)
        self.hidden_8 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_8.setObjectName("hidden_8")
        self.waveLengthLayout.addWidget(self.hidden_8, 7, 4, 1, 1)
        self.Normalization.addLayout(self.waveLengthLayout)
        self.index = QtWidgets.QSpinBox(self.groupBox)
        self.index.setProperty("value", 1)
        self.index.setObjectName("index")
        self.Normalization.addWidget(self.index)
        self.addDelRangeLayout = QtWidgets.QHBoxLayout()
        self.addDelRangeLayout.setObjectName("addDelRangeLayout")
        self.add_range_button = QtWidgets.QPushButton(self.groupBox)
        self.add_range_button.setObjectName("add_range_button")
        self.addDelRangeLayout.addWidget(self.add_range_button)
        self.delete_range_button = QtWidgets.QPushButton(self.groupBox)
        self.delete_range_button.setObjectName("delete_range_button")
        self.addDelRangeLayout.addWidget(self.delete_range_button)
        self.Normalization.addLayout(self.addDelRangeLayout)
        self.verticalLayout_3.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Normalization"))
        self.chooseDataLabel.setText(("Choose data"))
        self.varToNormalizeLabel.setText(("Variable to normalize"))
        self.hidden_6.setText(("Hidden"))
        self.hidden_4.setText(("Hidden"))
        self.hidden_1.setText(("Hidden"))
        self.minWvlLabel.setText(("1 Minimum wavelength"))
        self.maxWvlLabel.setText(("Maximum wavelength"))
        self.minWvlLabel_2.setText(("2 Minimum wavelength"))
        self.maxWvlLabel_2.setText(("Maximum wavelength"))
        self.minWvlLabel_3.setText(("3 Minimum wavelength"))
        self.maxWvlLabel_3.setText(("Maximum wavelength"))
        self.minWvlLabel_4.setText(("4 Minimum wavelength"))
        self.maxWvlLabel_4.setText(("Maximum wavelength"))
        self.minWvlLabel_5.setText(("5 Minimum wavelength"))
        self.maxWvlLabel_5.setText(("Maximum wavelength"))
        self.minWvlLabel_6.setText(("6 Minimum wavelength"))
        self.maxWvlLabel_6.setText(("Maximum wavelength"))
        self.minWvlLabel_7.setText(("7 Minimum wavelength"))
        self.maxWvlLabel_7.setText(("Maximum wavelength"))
        self.minWvlLabel_8.setText(("8 Minimum wavelength"))
        self.maxWvlLabel_8.setText(("Maximum wavelength"))
        self.minWvlLabel_9.setText(("9 Minimum wavelength"))
        self.maxWvlLabel_9.setText(("Maximum wavelength"))
        self.minWvlLabel_10.setText(("10 Minimum wavelength"))
        self.maxWvlLabel_10.setText(("Maximum wavelength"))
        self.minWvlLabel_11.setText(("11 Minimum wavelength"))
        self.maxWvlLabel_11.setText(("Maximum wavelength"))
        self.minWvlLabel_12.setText(("12 Minimum wavelength"))
        self.maxWvlLabel_12.setText(("Maximum wavelength"))
        self.minWvlLabel_13.setText(("13 Minimum wavelength"))
        self.maxWvlLabel_13.setText(("Maximum wavelength"))
        self.minWvlLabel_14.setText(("14 Minimum wavelength"))
        self.maxWvlLabel_14.setText(("Maximum wavelength"))
        self.minWvlLabel_15.setText(("15 Minimum wavelength"))
        self.maxWvlLabel_15.setText(("Maximum wavelength"))
        self.hidden_5.setText(("Hidden"))
        self.hidden_7.setText(("Hidden"))
        self.hidden_3.setText(("Hidden"))
        self.hidden_9.setText(("Hidden"))
        self.hidden_2.setText(("Hidden"))
        self.hidden_10.setText(("Hidden"))
        self.hidden_13.setText(("Hidden"))
        self.hidden_11.setText(("Hidden"))
        self.hidden_12.setText(("Hidden"))
        self.hidden_14.setText(("Hidden"))
        self.hidden_15.setText(("Hidden"))
        self.hidden_8.setText(("Hidden"))
        self.add_range_button.setText(("Add Range"))
        self.delete_range_button.setText(("Delete Range"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

