# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.cLabel = QtWidgets.QLabel(self.formGroupBox)
        self.cLabel.setObjectName("cLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.cLabel)
        self.cLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.cLineEdit.setProperty("value", 1.0)
        self.cLineEdit.setObjectName("cLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cLineEdit)
        self.epsilonLabel = QtWidgets.QLabel(self.formGroupBox)
        self.epsilonLabel.setObjectName("epsilonLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.epsilonLabel)
        self.epsilonLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.epsilonLineEdit.setProperty("value", 0.1)
        self.epsilonLineEdit.setObjectName("epsilonLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.epsilonLineEdit)
        self.kernelLabel = QtWidgets.QLabel(self.formGroupBox)
        self.kernelLabel.setObjectName("kernelLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.kernelLabel)
        self.kernel_list = QtWidgets.QListWidget(self.formGroupBox)
        self.kernel_list.setMaximumSize(QtCore.QSize(16777215, 120))
        self.kernel_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.kernel_list.setObjectName("kernel_list")
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.kernel_list)
        self.degreeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.degreeLabel.setObjectName("degreeLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.degreeLabel)
        self.degreeLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.degreeLineEdit.setObjectName("degreeLineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.degreeLineEdit)
        self.coeff0Label = QtWidgets.QLabel(self.formGroupBox)
        self.coeff0Label.setObjectName("coeff0Label")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.coeff0Label)
        self.coeff0LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.coeff0LineEdit.setObjectName("coeff0LineEdit")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.coeff0LineEdit)
        self.shrinkingLabel = QtWidgets.QLabel(self.formGroupBox)
        self.shrinkingLabel.setObjectName("shrinkingLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.shrinkingLabel)
        self.shrinking_list = QtWidgets.QListWidget(self.formGroupBox)
        self.shrinking_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.shrinking_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.shrinking_list.setObjectName("shrinking_list")
        item = QtWidgets.QListWidgetItem()
        self.shrinking_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.shrinking_list.addItem(item)
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.shrinking_list)
        self.toleranceLabel = QtWidgets.QLabel(self.formGroupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.toleranceLineEdit.setProperty("decimals", 3)
        self.toleranceLineEdit.setProperty("value", 0.001)
        self.toleranceLineEdit.setObjectName("toleranceLineEdit")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.toleranceLineEdit)
        self.maxIterationsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.maxIterationsLabel.setObjectName("maxIterationsLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.maxIterationsLabel)
        self.maxIterationsLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.maxIterationsLineEdit.setProperty("minimum", -1)
        self.maxIterationsLineEdit.setProperty("maximum", 9999999)
        self.maxIterationsLineEdit.setProperty("value", -1)
        self.maxIterationsLineEdit.setObjectName("maxIterationsLineEdit")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.maxIterationsLineEdit)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setToolTip(("<html><head/><body><p>The method of Support Vector Classification can be extended to solve regression problems. This method is called Support Vector Regression.</p><p>The model produced by support vector classification (as described above) depends only on a subset of the training data, because the cost function for building the model does not care about training points that lie beyond the margin. Analogously, the model produced by Support Vector Regression depends only on a subset of the training data, because the cost function for building the model ignores any training data close to the model prediction.</p></body></html>"))
        self.cLabel.setText(("Penalty Parameter"))
        self.epsilonLabel.setText(("Epsilon"))
        self.kernelLabel.setText(("Kernel"))
        __sortingEnabled = self.kernel_list.isSortingEnabled()
        self.kernel_list.setSortingEnabled(False)
        item = self.kernel_list.item(0)
        item.setText(("Radial Basis Function"))
        item = self.kernel_list.item(1)
        item.setText(("Linear"))
        item = self.kernel_list.item(2)
        item.setText(("Polynomial"))
        item = self.kernel_list.item(3)
        item.setText(("Sigmoid"))
        item = self.kernel_list.item(4)
        item.setText(("Precomputed"))
        self.kernel_list.setSortingEnabled(__sortingEnabled)
        self.degreeLabel.setText(("Polynomial Degree"))
        self.coeff0Label.setText(("Coeff 0"))
        self.shrinkingLabel.setText(("Shrinking"))
        __sortingEnabled = self.shrinking_list.isSortingEnabled()
        self.shrinking_list.setSortingEnabled(False)
        item = self.shrinking_list.item(0)
        item.setText(("True"))
        item = self.shrinking_list.item(1)
        item.setText(("False"))
        self.shrinking_list.setSortingEnabled(__sortingEnabled)
        self.toleranceLabel.setText(("Tolerance"))
        self.maxIterationsLabel.setText(("Max Iterations"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

