# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.colName_3 = QtWidgets.QComboBox(self.groupBox)
        self.colName_3.setObjectName("colName_3")
        self.gridLayout_2.addWidget(self.colName_3, 4, 1, 1, 1)
        self.colName_2 = QtWidgets.QComboBox(self.groupBox)
        self.colName_2.setObjectName("colName_2")
        self.gridLayout_2.addWidget(self.colName_2, 3, 1, 1, 1)
        self.colName_5 = QtWidgets.QComboBox(self.groupBox)
        self.colName_5.setObjectName("colName_5")
        self.gridLayout_2.addWidget(self.colName_5, 6, 1, 1, 1)
        self.value_3 = QtWidgets.QComboBox(self.groupBox)
        self.value_3.setObjectName("value_3")
        self.gridLayout_2.addWidget(self.value_3, 4, 3, 1, 1)
        self.colName_1 = QtWidgets.QComboBox(self.groupBox)
        self.colName_1.setObjectName("colName_1")
        self.gridLayout_2.addWidget(self.colName_1, 2, 1, 1, 1)
        self.operator_1 = QtWidgets.QComboBox(self.groupBox)
        self.operator_1.setObjectName("operator_1")
        self.operator_1.addItem("")
        self.operator_1.addItem("")
        self.operator_1.addItem("")
        self.operator_1.addItem("")
        self.operator_1.addItem("")
        self.gridLayout_2.addWidget(self.operator_1, 2, 2, 1, 1)
        self.logic_2 = QtWidgets.QComboBox(self.groupBox)
        self.logic_2.setObjectName("logic_2")
        self.logic_2.addItem("")
        self.logic_2.addItem("")
        self.logic_2.addItem("")
        self.gridLayout_2.addWidget(self.logic_2, 3, 4, 1, 1)
        self.operator_4 = QtWidgets.QComboBox(self.groupBox)
        self.operator_4.setObjectName("operator_4")
        self.operator_4.addItem("")
        self.operator_4.addItem("")
        self.operator_4.addItem("")
        self.operator_4.addItem("")
        self.operator_4.addItem("")
        self.gridLayout_2.addWidget(self.operator_4, 5, 2, 1, 1)
        self.value_1 = QtWidgets.QComboBox(self.groupBox)
        self.value_1.setObjectName("value_1")
        self.gridLayout_2.addWidget(self.value_1, 2, 3, 1, 1)
        self.value_2 = QtWidgets.QComboBox(self.groupBox)
        self.value_2.setObjectName("value_2")
        self.gridLayout_2.addWidget(self.value_2, 3, 3, 1, 1)
        self.operator_3 = QtWidgets.QComboBox(self.groupBox)
        self.operator_3.setObjectName("operator_3")
        self.operator_3.addItem("")
        self.operator_3.addItem("")
        self.operator_3.addItem("")
        self.operator_3.addItem("")
        self.operator_3.addItem("")
        self.gridLayout_2.addWidget(self.operator_3, 4, 2, 1, 1)
        self.value_5 = QtWidgets.QComboBox(self.groupBox)
        self.value_5.setObjectName("value_5")
        self.gridLayout_2.addWidget(self.value_5, 6, 3, 1, 1)
        self.operator_2 = QtWidgets.QComboBox(self.groupBox)
        self.operator_2.setObjectName("operator_2")
        self.operator_2.addItem("")
        self.operator_2.addItem("")
        self.operator_2.addItem("")
        self.operator_2.addItem("")
        self.operator_2.addItem("")
        self.gridLayout_2.addWidget(self.operator_2, 3, 2, 1, 1)
        self.colName_4 = QtWidgets.QComboBox(self.groupBox)
        self.colName_4.setObjectName("colName_4")
        self.gridLayout_2.addWidget(self.colName_4, 5, 1, 1, 1)
        self.logic_1 = QtWidgets.QComboBox(self.groupBox)
        self.logic_1.setObjectName("logic_1")
        self.logic_1.addItem("")
        self.logic_1.addItem("")
        self.logic_1.addItem("")
        self.gridLayout_2.addWidget(self.logic_1, 2, 4, 1, 1)
        self.chooseData = QtWidgets.QComboBox(self.groupBox)
        self.chooseData.setObjectName("chooseData")
        self.gridLayout_2.addWidget(self.chooseData, 0, 2, 1, 1)
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.gridLayout_2.addWidget(self.chooseDataLabel, 0, 1, 1, 1)
        self.remove_label = QtWidgets.QLabel(self.groupBox)
        self.remove_label.setObjectName("remove_label")
        self.gridLayout_2.addWidget(self.remove_label, 1, 1, 1, 1)
        self.logic_4 = QtWidgets.QComboBox(self.groupBox)
        self.logic_4.setObjectName("logic_4")
        self.logic_4.addItem("")
        self.logic_4.addItem("")
        self.logic_4.addItem("")
        self.gridLayout_2.addWidget(self.logic_4, 5, 4, 1, 1)
        self.value_4 = QtWidgets.QComboBox(self.groupBox)
        self.value_4.setObjectName("value_4")
        self.gridLayout_2.addWidget(self.value_4, 5, 3, 1, 1)
        self.operator_5 = QtWidgets.QComboBox(self.groupBox)
        self.operator_5.setObjectName("operator_5")
        self.operator_5.addItem("")
        self.operator_5.addItem("")
        self.operator_5.addItem("")
        self.operator_5.addItem("")
        self.operator_5.addItem("")
        self.gridLayout_2.addWidget(self.operator_5, 6, 2, 1, 1)
        self.logic_3 = QtWidgets.QComboBox(self.groupBox)
        self.logic_3.setObjectName("logic_3")
        self.logic_3.addItem("")
        self.logic_3.addItem("")
        self.logic_3.addItem("")
        self.gridLayout_2.addWidget(self.logic_3, 4, 4, 1, 1)
        self.hidden_2 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_2.setObjectName("hidden_2")
        self.gridLayout_2.addWidget(self.hidden_2, 3, 5, 1, 1)
        self.hidden_3 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_3.setObjectName("hidden_3")
        self.gridLayout_2.addWidget(self.hidden_3, 4, 5, 1, 1)
        self.hidden_4 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_4.setObjectName("hidden_4")
        self.gridLayout_2.addWidget(self.hidden_4, 5, 5, 1, 1)
        self.hidden_5 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_5.setObjectName("hidden_5")
        self.gridLayout_2.addWidget(self.hidden_5, 6, 5, 1, 1)
        self.gridLayout.addLayout(self.gridLayout_2, 4, 0, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Remove Rows"))
        self.operator_1.setItemText(0, ("="))
        self.operator_1.setItemText(1, (">"))
        self.operator_1.setItemText(2, ("<"))
        self.operator_1.setItemText(3, (">="))
        self.operator_1.setItemText(4, ("<="))
        self.logic_2.setItemText(0, ("-"))
        self.logic_2.setItemText(1, ("and"))
        self.logic_2.setItemText(2, ("or"))
        self.operator_4.setItemText(0, ("="))
        self.operator_4.setItemText(1, (">"))
        self.operator_4.setItemText(2, ("<"))
        self.operator_4.setItemText(3, (">="))
        self.operator_4.setItemText(4, ("<="))
        self.operator_3.setItemText(0, ("="))
        self.operator_3.setItemText(1, (">"))
        self.operator_3.setItemText(2, ("<"))
        self.operator_3.setItemText(3, (">="))
        self.operator_3.setItemText(4, ("<="))
        self.operator_2.setItemText(0, ("="))
        self.operator_2.setItemText(1, (">"))
        self.operator_2.setItemText(2, ("<"))
        self.operator_2.setItemText(3, (">="))
        self.operator_2.setItemText(4, ("<="))
        self.logic_1.setItemText(0, ("-"))
        self.logic_1.setItemText(1, ("and"))
        self.logic_1.setItemText(2, ("or"))
        self.chooseDataLabel.setText(("Choose Data:"))
        self.remove_label.setText(("Remove rows where:"))
        self.logic_4.setItemText(0, ("-"))
        self.logic_4.setItemText(1, ("and"))
        self.logic_4.setItemText(2, ("or"))
        self.operator_5.setItemText(0, ("="))
        self.operator_5.setItemText(1, (">"))
        self.operator_5.setItemText(2, ("<"))
        self.operator_5.setItemText(3, (">="))
        self.operator_5.setItemText(4, ("<="))
        self.logic_3.setItemText(0, ("-"))
        self.logic_3.setItemText(1, ("and"))
        self.logic_3.setItemText(2, ("or"))
        self.hidden_2.setText(("Hidden"))
        self.hidden_3.setText(("Hidden"))
        self.hidden_4.setText(("Hidden"))
        self.hidden_5.setText(("Hidden"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

